<?php
/**
 * Plugin Name: GuTemplate - Pro Templates Library for WordPress
 * Description: Improve the new WordPress editor with beautiful and modern blocks to design stunning websites in just a flash!
 * Version: 1.0.0
 * Author: AA-Team
 * Author URI: http://www.aa-team.com
 * Text Domain: aatgutemplate
 * Domain Path: /languages
 *
 * @package aatgutemplate
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if (class_exists('AAT_BlockDesign') != true) {
	class AAT_BlockDesign
	{
		protected static $instance = null;

		public static function getInstance()
		{
			if (!isset(static::$instance)) {
				static::$instance = new static;
			}
			return static::$instance;
		}

		protected function __construct()
		{
			add_action( 'after_setup_theme', array( $this, 'setup_theme_colors' ), 999 );

			if( is_admin() ){
				add_action( 'enqueue_block_editor_assets', array( $this, 'editor_assets' ) );
				add_action('admin_footer', array( $this, 'block_design_wrapper' ) );
			}else{
				add_action( 'wp_enqueue_scripts', array( $this, 'frontend_assets' ) );
			}
			
			add_action( 'wp_enqueue_scripts', array( $this, 'fonts_loader' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'fonts_loader' ) );
			add_filter( 'init', array( $this, 'register_meta' ) );
		}

		public function register_meta() 
		{
  			load_plugin_textdomain( 'aatgutemplate', false, basename( dirname( __FILE__ ) ) . '/languages' ); 

			register_meta(
				'post', '_blocks_design_attr', array(
					'show_in_rest'  => true,
					'single'        => true,
					'auth_callback' => function() {
						return current_user_can( 'edit_posts' );
					},
				)
			);

			register_meta(
				'post', '_blocks_design_hover_state', array(
					'show_in_rest'  => true,
					'single'        => true,
					'auth_callback' => function() {
						return current_user_can( 'edit_posts' );
					},
				)
			);
		}

		public function fonts_loader()
		{
			global $post;
			
			// load default font
			wp_enqueue_style(
				'block/design/default-font',
				'//fonts.googleapis.com/css?family=Roboto:400,700'
			);
			
			if ( $post && isset( $post->ID ) ) {

				$fonts = get_post_meta( $post->ID, '_blocks_design_attr', true );

				if ( ! empty( $fonts ) ) {

					$fonts = array_unique( explode( ',', $fonts ) );

					$system = array(
						'Arial',
						'Tahoma',
						'Verdana',
						'Helvetica',
						'Times New Roman',
						'Trebuchet MS',
						'Georgia',
					);

					$gfonts = '';

					$gfonts_attr = ':100,100italic,200,200italic,300,300italic,400,400italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic';

					foreach ( $fonts as $font ) {
						if ( ! in_array( $font, $system, true ) && ! empty( $font ) ) {
							$gfonts .= str_replace( ' ', '+', trim( $font ) ) . $gfonts_attr . '|';
						}
					}

					if ( ! empty( $gfonts ) ) {
						$query_args = array(
							'family' => $gfonts,
						);

						wp_register_style(
							'blocksdesign-block-fonts',
							add_query_arg( $query_args, '//fonts.googleapis.com/css' )
						);

						wp_enqueue_style( 'blocksdesign-block-fonts' );
					}

					// Reset.
					$gfonts = '';
				}
			}
		}

		public function setup_theme_colors()
		{
			add_theme_support( 'editor-color-palette', array(
		        array(
		            'name' => esc_html__( 'strong magenta', 'aatgutemplate' ),
		            'slug' => 'strong-magenta',
		            'color' => '#a156b4',
		        ),
		        array(
		            'name' => esc_html__( 'light grayish magenta', 'aatgutemplate' ),
		            'slug' => 'light-grayish-magenta',
		            'color' => '#d0a5db',
		        ),
		        array(
		            'name' => esc_html__( 'pale pink', 'aatgutemplate' ),
		            'slug' => 'pale-pink',
		            'color' => '#f78da7',
		        ),
		        array(
		            'name' => esc_html__( 'vivid red', 'aatgutemplate' ),
		            'slug' => 'vivid-red',
		            'color' => '#cf2e2e',
		        ),
		        array(
		            'name' => esc_html__( 'luminous vivid amber', 'aatgutemplate' ),
		            'slug' => 'luminous-vivid-amber',
		            'color' => '#fcb900',
		        ),
		        array(
		            'name' => esc_html__( 'vivid cyan blue', 'aatgutemplate' ),
		            'slug' => 'vivid-cyan-blue',
		            'color' => '#0693e3',
		        ),
		        array(
		            'name' => esc_html__( 'vivid cyan turquoise', 'aatgutemplate' ),
		            'slug' => 'vivid-cyan-turquoise',
		            'color' => '#00BCD4',
		        ),
		        array(
		            'name' => esc_html__( 'vivid cyan green', 'aatgutemplate' ),
		            'slug' => 'vivid-cyan-green',
		            'color' => '#00C853',
		        ),
		        array(
		            'name' => esc_html__( 'very light gray', 'aatgutemplate' ),
		            'slug' => 'very-light-gray',
		            'color' => '#eee',
		        ),
		        array(
		            'name' => esc_html__( 'vivid white', 'aatgutemplate' ),
		            'slug' => 'vivid-white',
		            'color' => '#fff',
		        ),
		        array(
		            'name' => esc_html__( 'very dark gray', 'aatgutemplate' ),
		            'slug' => 'very-dark-gray',
		            'color' => '#444',
		        )
		    ) );
		}

		public function block_design_wrapper()
		{
			echo '<div id="blocks_design-wrapper"></div>';
		}

		public function frontend_assets()
		{
			wp_enqueue_style(
				'block/design',
				plugins_url( 'build/frontend/frontend.view.css', __FILE__ )
			);

			wp_enqueue_script(
				'block/design',
				plugins_url( 'build/frontend/frontend.build.js', __FILE__ )
			);

			wp_localize_script( 'block/design', 'BLOCKDESIGN', array(
				'assets_url' => plugins_url( '/', __FILE__ ),
				'fonts' => array()
			) );
		}

		private function templates()
		{
			$templates = array();
			$categs = glob( dirname( __FILE__ ) . '/templates/*' );
			if( $categs && count( $categs ) ){
				foreach ( $categs as $path ) {
					$_alias = explode("/", $path );
					$alias = end( $_alias );
					
					$_name_alias = explode("_", $alias);
					$name_alias = end( $_name_alias );

					$templates[$alias] = array();
					$templates[$alias]['name'] = ucwords( str_replace( "-", " ", $name_alias ) );

					$cc = 0;
					foreach( glob( $path . "/*/code.html" ) as $template ){ 
						$template_dir = str_replace( "/code.html", '', $template );

						$images = glob( $template_dir . "/*.jpg" );
						if( $images && count($images) && isset($images[0]) ){
							$templates[$alias][$cc]['image'] = str_replace( dirname( __FILE__ ) . '/', '', $images[0]);
							$templates[$alias][$cc]['code'] = str_replace( dirname( __FILE__ ) . '/', '', $template);
						}

						$cc++;
					}

				}
			}

			return $templates;
		}

		public function editor_assets()
		{
			wp_enqueue_script(
				'block/design',
				plugins_url( 'build/block/block.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-editor' )
			);

			wp_enqueue_script(
				'separator/design',
				plugins_url( 'build/separator/separator.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-editor' )
			);

			wp_enqueue_script(
				'icons/design',
				plugins_url( 'build/icons/icons.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-editor' )
			);

			wp_localize_script( 'block/design', 'BLOCKDESIGN', array(
				'assets_url' => plugins_url( '/', __FILE__ ),
				'fonts' => array(),
				'add_template_fonts' => array(),
				'toolbar_btn_added' => false,
				'templates' => $this->templates(),
				'hovers' => array(),
			) );

			wp_enqueue_style(
				'icons/design',
				plugins_url( 'build/icons/icons.editor.css', __FILE__ ),
				array( 'wp-edit-blocks' )
			);

			wp_enqueue_script(
				'plugin/design',
				plugins_url( 'build/plugin/plugin.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-edit-post', 'lodash' )
			);

			wp_enqueue_script(
				'plugin/typo',
				plugins_url( 'build/typo/typo.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-edit-post', 'lodash' )
			);

			wp_enqueue_style(
				'plugin/design',
				plugins_url( 'build/plugin/plugin.editor.css', __FILE__ ),
				array( 'wp-edit-blocks' )
			);
			
			wp_enqueue_style(
				'block/design',
				plugins_url( 'build/backend/backend.editor.css', __FILE__ ),
				array( 'wp-edit-blocks' )
			);
		}
	}
}

$AAT_BlockDesign = AAT_BlockDesign::getInstance();
function AAT_BlockDesign() {
	global $AAT_BlockDesign;
	return $AAT_BlockDesign;
}